@@ -6,7 +6,7 @@
 #' @examples
 #' weight()
 #' @export
-weight <- function(range = c(-10, 0), trans = log10_trans()) {
+weight <- function(range = c(-10, 0), trans = transform_log10()) {
   new_quant_param(
     type = "double",
     range = range,
